@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from facebook_api.parser import FacebookParser, FacebookParseError
-import simplejson as json
+from django.utils import simplejson as json
 
 class FacebookPageFansParser(FacebookParser):
 
